==> knative-model-6.3.1-sources.jar: io/fabric8/knative/eventing/contrib/kafka/v1beta1/SecretValueFromSourceFluentImpl.java <==
package io.fabric8.knative.eventing.contrib.kafka.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.SecretKeySelector;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SecretValueFromSourceFluentImpl<A extends SecretValueFromSourceFluent<A>> extends BaseFluent<A> implements SecretValueFromSourceFluent<A>{
  public SecretValueFromSourceFluentImpl() {
  }
  public SecretValueFromSourceFluentImpl(SecretValueFromSource instance) {
    this.withSecretKeyRef(instance.getSecretKeyRef()); 
  }
  private SecretKeySelector secretKeyRef;
  public SecretKeySelector getSecretKeyRef() {
    return this.secretKeyRef;
  }
  public A withSecretKeyRef(SecretKeySelector secretKeyRef) {
    this.secretKeyRef=secretKeyRef; return (A) this;
  }
  public Boolean hasSecretKeyRef() {
    return this.secretKeyRef != null;
  }
  public A withNewSecretKeyRef(String key,String name,Boolean optional) {
    return (A)withSecretKeyRef(new SecretKeySelector(key, name, optional));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    SecretValueFromSourceFluentImpl that = (SecretValueFromSourceFluentImpl) o;
    if (secretKeyRef != null ? !secretKeyRef.equals(that.secretKeyRef) :that.secretKeyRef != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(secretKeyRef,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (secretKeyRef != null) { sb.append("secretKeyRef:"); sb.append(secretKeyRef); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> knative-model-6.7.1-sources.jar: io/fabric8/knative/eventing/contrib/kafka/v1beta1/SecretValueFromSourceFluentImpl.java <==
package io.fabric8.knative.eventing.contrib.kafka.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.SecretKeySelector;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class SecretValueFromSourceFluentImpl<A extends SecretValueFromSourceFluent<A>> extends BaseFluent<A> implements SecretValueFromSourceFluent<A>{
  public SecretValueFromSourceFluentImpl() {
  }
  public SecretValueFromSourceFluentImpl(SecretValueFromSource instance) {
    if (instance != null) {
      this.withSecretKeyRef(instance.getSecretKeyRef());
    }
  }
  private SecretKeySelector secretKeyRef;
  public SecretKeySelector getSecretKeyRef() {
    return this.secretKeyRef;
  }
  public A withSecretKeyRef(SecretKeySelector secretKeyRef) {
    this.secretKeyRef=secretKeyRef; return (A) this;
  }
  public Boolean hasSecretKeyRef() {
    return this.secretKeyRef != null;
  }
  public A withNewSecretKeyRef(String key,String name,Boolean optional) {
    return (A)withSecretKeyRef(new SecretKeySelector(key, name, optional));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SecretValueFromSourceFluentImpl that = (SecretValueFromSourceFluentImpl) o;
    if (!java.util.Objects.equals(secretKeyRef, that.secretKeyRef)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(secretKeyRef,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (secretKeyRef != null) { sb.append("secretKeyRef:"); sb.append(secretKeyRef); }
    sb.append("}");
    return sb.toString();
  }
  
}
